Bomcheck Troubleshooting

# Troubleshooting

1. Multilevel BOMs
2. SolidWorks BOM not processed
3. Assembly pn in Syteline, but SolidWorks BOM not processed.
4. SyteLine BOM not processed
5. Empty I Q D U fields
6. SW's lengths not converted to FT
7. Program crashed due to missing columns
8. Unable to open config.txt file.
9. What accuracy should lengths be?
10. Column name conflicts

1. Multilevel BOMs. SolidWorks BOMs are sometimes multilevel (subassemblies within the main assembly), and the BOMs from SyteLine can be also. Can bomcheck handle these? Yes. In fact, a subassembly in a subassembly in a subassembly, and so forth, can exist. Bomcheck handles any level of subassemblies.

For a multilevel SolidWorks BOM to work, the Item numbers in the BOM must be numbered to indicate the level; e.g. 1, 2, 3, 3.1, 3.2, 3.2.1, 3.2.2, 3.2.2.1, 3.2.2.2, 3.3 and so forth. For a multilevel SyteLine BOM to work, the BOM must have a column titled Level with values in that column looking like 0, 1, 2, 2.1, 2.2, 2.2.1, 2.2.2, etc. These formats are standard for SolidWorks and Syteline.

2. SolidWorks BOM not processed. A SolidWorks BOM I submitted wasn't compared to a SyteLine BOM. The only thing that happend is that the BOM was transformed to look like a BOM from SyteLine. What happened? Answer: no SyteLine BOM was found to compare it to the SolidWorks BOM.

3. Assembly pn in Syteline, but SolidWorks BOM not processed. I have a particular assembly/subassembly BOM entered into SyteLine but the bomcheck program reports that that it cannot find the BOM. Why? For that particular assembly, the parts of that assembly have not been entered yet into SyteLine.

4. SyteLine BOM not processed. A SyteLine BOM was submitted but nothing happened to indicate that the BOM had even been looked at. What happened? Answer: bomcheck ignores all BOMs from SyteLine for which it can't find a SolidWorks BOM to compare it to.

5. Empty I Q D U fields. The I, Q, D, and U values that indicate pass/fail results are shown empty ( ) for a particular part number. Dashes and Xs (‒‒‒‒ or ‒‒X‒, etc.) should be shown. If this is not the case, then it indicates that a part number is repeated in the SyteLine BOM. Duplicate part numbers should not be in a SyteLine BOM!

6. SW's lengths not converted to FT. A part length in SolidWorks did not convert of feet in order to compare to a length in SyteLine. Why not? In the bom check you'll see that the unit of measure for length from SolidWorks is EA when it should be FT. This means that the length column is not shown on the SolidWorks BOM as it should be.

7. Crash... missing columns. Bomcheck crashed complaining of missing columns. What went wrong? Answer: several things could have happened. A SyteLine BOM may have been mistakenly labeled as as SolidWorks BOM (had _sw.xlsx extension). A SolidWorks BOM may have been labeled as a SyteLine BOM (had a _sl.xlsx extension). The column names for a SolidWorks BOM may not be on the second row of the SW Excel sheet (Dekker's SW BOMs has the assembly part number on the the first row). The column names for a SyteLine BOM are not on the first row. In short, the arrangement of the BOM in the Excel sheet is not in it's normal arrangement.

8. Unable to open config.txt (bomcheckgui only) The program reports that it cannot open up a file named config.txt. What is that about? Answer: Whenever a user makes a settings change (File > Settings), bomcheckgui remembers those settings for future use by saving those settings in a file named config.txt. In that file is also saved the last accessed folder containing BOMs. That file is located in a user's settings folder. The file is at C:\Users\username\AppData\Local\bomcheck\config.txt. (The bomcheckgui program automatically creates this file.) Perhaps user rights were somehow severed??? Contact the IT manager for help.

9. What accuracy should lengths be? If you are running the bomcheckgui program, at File > Settings the decimal place accuracy is set for rounding bomcheck lengths (e.g. .83 ft). An accuracy of 2 (for feet) is a good number. This means that if two places are shown, then the length is accurate to within ±0.06 inches. This is close enough. Then if the lengths shown in SolidWorks and SyteLine differ by more than ±0.06 inches, then bomcheck will flag this as an error. Of course, a greater level of accuracy can be set.

10. Conflicting column names withing the same BOM. I have a BOM from my ERP program that contains two different column names, either of which could contain part numbers of parts, for example Material and Item. How does bomcheck resolve which column to get part numbers from? Adjust the bomcheck.cfg file. The name that appears first in the list of potential column names for parts will take precedent.

last updated: 6/5/2022